@@ -32,6 +32,9 @@ bash test-burden.sh
 # Test basic functionality
 bash test-columns.sh
 
+# Test cadd scores
+bash test-cadd.sh
+
 # Test loading functionality
 bash test-load.sh
 
@@ -91,6 +94,9 @@ bash test-auto-rec.sh
 # Test denovo tool
 bash test-de-novo.sh
 
+# Test wildcards
+bash test-wildcards.sh
+
 # cleanup
 rm ./*.db
 rm ./file.dot
